Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(267)

Unified Diff: chrome/browser/sync/glue/ui_data_type_controller.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/ui_data_type_controller.h
diff --git a/chrome/browser/sync/glue/ui_data_type_controller.h b/chrome/browser/sync/glue/ui_data_type_controller.h
index ce3d64286b8669418bc8e2b5101db3a453851996..8120f58e5d2250eb88605de096fe53354ca25965 100644
--- a/chrome/browser/sync/glue/ui_data_type_controller.h
+++ b/chrome/browser/sync/glue/ui_data_type_controller.h
@@ -18,10 +18,16 @@
class Profile;
class ProfileSyncService;
class ProfileSyncComponentsFactory;
+
+namespace base {
+class TimeDelta;
+}
+
+namespace csync {
class SyncableService;
class SyncError;
+}
-namespace base { class TimeDelta; }
namespace browser_sync {
// Implementation for datatypes that reside on the (UI thread). This is the same
@@ -73,7 +79,7 @@ class UIDataTypeController : public DataTypeController {
virtual void OnModelLoaded() OVERRIDE;
// Helper methods for cleaning up state and invoking the start callback.
- virtual void StartFailed(StartResult result, const SyncError& error);
+ virtual void StartFailed(StartResult result, const csync::SyncError& error);
virtual void StartDone(StartResult result);
// Record association time.
@@ -104,7 +110,7 @@ class UIDataTypeController : public DataTypeController {
//
// Note: we use refcounting here primarily so that we can keep a uniform
// SyncableService API, whether the datatype lives on the UI thread or not
// (a SyncableService takes ownership of its SyncChangeProcessor when
// MergeDataAndStartSyncing is called). This will help us eventually merge the
// two datatype controller implementations (for ui and non-ui thread
// datatypes).
@@ -112,7 +118,7 @@ class UIDataTypeController : public DataTypeController {
// A weak pointer to the actual local syncable service, which performs all the
// real work. We do not own the object.
- base::WeakPtr<SyncableService> local_service_;
+ base::WeakPtr<csync::SyncableService> local_service_;
private:
// Associate the sync model with the service's model, then start syncing.
« no previous file with comments | « chrome/browser/sync/glue/typed_url_model_associator_unittest.cc ('k') | chrome/browser/sync/glue/ui_data_type_controller.cc » ('j') | no next file with comments »
@@ -104,7 +110,7 @@ class UIDataTypeController : public DataTypeController {
// Note: we use refcounting here primarily so that we can keep a uniform
// SyncableService API, whether the datatype lives on the UI thread or not
- // (a SyncableService takes ownership of its SyncChangeProcessor when
+ // (a csync::SyncableService takes ownership of its SyncChangeProcessor when
// MergeDataAndStartSyncing is called). This will help us eventually merge the
// two datatype controller implementations (for ui and non-ui thread

Powered by Google App Engine
This is Rietveld 408576698